@@ -20,13 +20,20 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 require 'yaml'
 require 'uri'
 require 'feed2imap/imap'
+require 'feed2imap/maildir'
+require 'etc'
+require 'socket'
 
 # Default cache file
 DEFCACHE = ENV['HOME'] + '/.feed2imap.cache'
 
+# Hostname and login name of the current user
+HOSTNAME = Socket.gethostname
+LOGNAME = Etc.getlogin
+
 # Feed2imap configuration
 class F2IConfig
-  attr_reader :imap_accounts, :cache, :feeds, :dumpdir, :updateddebug, :max_failures, :include_images
+  attr_reader :imap_accounts, :cache, :feeds, :dumpdir, :updateddebug, :max_failures, :include_images, :default_email, :hostname
 
   # Load the configuration from the IO stream
   # TODO should do some sanity check on the data read.
@@ -39,13 +46,21 @@ class F2IConfig
     @max_failures = (@conf['max-failures'] || 10).to_i
     @updateddebug =  (@conf['debug-updated'] and @conf['debug-updated'] != 'false')
     @include_images = (@conf['include-images'] and @conf['include-images'] != 'false')
+    @default_email = (@conf['default-email'] || "#{LOGNAME}@#{HOSTNAME}")
+    ImapAccount.no_ssl_verify = (@conf['disable-ssl-verification'] and @conf['disable-ssl-verification'] != 'false')
+    @hostname = HOSTNAME # FIXME: should this be configurable as well?
     @imap_accounts = ImapAccounts::new
+    maildir_account = MaildirAccount::new
     @conf['feeds'].each do |f|
       if f['disable'].nil?
         uri = URI::parse(f['target'].to_s)
         path = URI::unescape(uri.path)
         path = path[1..-1] if path[0,1] == '/'
-        @feeds.push(ConfigFeed::new(f, @imap_accounts.add_account(uri), path, self))
+        if uri.scheme == 'maildir'
+          @feeds.push(ConfigFeed::new(f, maildir_account, path, self))
+        else
+          @feeds.push(ConfigFeed::new(f, @imap_accounts.add_account(uri), path, self))
+        end
       end
     end
   end
