@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =end
 
 # Feed2Imap version
-F2I_VERSION = '0.9.4'
+F2I_VERSION = '1.0'
 F2I_WARNFETCHTIME = 10
 
 require 'feed2imap/config'
@@ -244,15 +244,15 @@ class Feed2Imap
         if !cacherebuild
           fn = f.name.gsub(/[^0-9A-Za-z]/,'')
           updateditems.each do |i|
-            id = "<#{fn}-#{i.cacheditem.index}@acme.com>"
-            email = item_to_mail(i, id, true, f.name, f.include_images, f.wrapto)
+            id = "<#{fn}-#{i.cacheditem.index}@#{@config.hostname}>"
+            email = item_to_mail(@config, i, id, true, f.name, f.include_images, f.wrapto)
             f.imapaccount.updatemail(f.folder, email,
                                      id, i.date || Time::new)
           end
           # reverse is needed to upload older items first (fixes gna#8986)
           newitems.reverse.each do |i|
-            id = "<#{fn}-#{i.cacheditem.index}@acme.com>"
-            email = item_to_mail(i, id, false, f.name, f.include_images, f.wrapto)
+            id = "<#{fn}-#{i.cacheditem.index}@#{@config.hostname}>"
+            email = item_to_mail(@config, i, id, false, f.name, f.include_images, f.wrapto)
             f.imapaccount.putmail(f.folder, email, i.date || Time::new)
           end
         end
